# (akien) The Vulkan SDK requires some care when updating.
# We only package SDK releases (sdk-%%{version}).
#
# There are many interdependent dependencies which need to be synced to specific
# "known good" commits for the APIs to be compatible.
#
# Upstream is now properly tagging `sdk-*` versions on each component, so the
# instructions below have been simplified.
# Find the latest SDK release by reviewing GitHub tags for e.g. Vulkan-Headers.
#
# Here's the build order.
# - A1 and A2 can be done in parallel.
# - 2. means that you should wait for 1. to finish, while 1.a. and 1.b. means
#   that both can be pushed in parallel.
#
# (A1) SPIRV stack:
# 1. spirv-headers
# 2. spirv-tools
# 3. glslang
#
# (A2) Vulkan stack:
# 1. vulkan-headers
# 2. vulkan-loader
# 3. vulkan-volk
# 4. vulkan-utility-libraries
#
# (B) Depends on A1 and A2 being completed:
# 1.a. vulkan-tools
# 1.b. vulkan-validation-layers
# 1.c. vkd3d
# 1.d. shaderc

%define __python %{__python3}

%define uname   Vulkan-Headers

Name:           vulkan-headers
Version:        1.4.309.0
Release:        %mkrel 1
Summary:        Vulkan header files and API registry
Group:          Development/C
License:        ASL 2.0
URL:            https://github.com/KhronosGroup/Vulkan-Headers
Source0:        https://github.com/KhronosGroup/Vulkan-Headers/archive/vulkan-sdk-%{version}/%{uname}-sdk-%{version}.tar.gz

BuildRequires:  cmake
BuildArch:      noarch

%description
Vulkan header files and API registry.

%prep
%autosetup -p1 -n %{uname}-vulkan-sdk-%{version}

%build
%cmake \
    -DVULKAN_HEADERS_ENABLE_MODULE=OFF
%cmake_build

%install
%cmake_install

%files
%doc README.md
%license LICENSE.md
%{_includedir}/vulkan/
%{_includedir}/vk_video/
%dir %{_datadir}/vulkan
%{_datadir}/vulkan/registry/
%{_datadir}/cmake/VulkanHeaders/


%changelog
* Mon Apr 21 2025 daviddavid <daviddavid> 1.4.309.0-1.mga10
+ Revision: 2177882
- update to 1.4.309.0 SDK

* Wed Jan 22 2025 daviddavid <daviddavid> 1.4.304.0-1.mga10
+ Revision: 2140468
- update to 1.4.304.0 SDK

* Fri Nov 15 2024 daviddavid <daviddavid> 1.3.296.0-1.mga10
+ Revision: 2116033
- update to 1.3.296.0 SDK

* Fri Aug 09 2024 papoteur <papoteur> 1.3.290.0-1.mga10
+ Revision: 2084320
- new version 1.3.290.0
- add cmake files

* Mon Nov 14 2022 akien <akien> 1.3.231.1-1.mga9
+ Revision: 1907189
- Vulkan SDK 1.3.231.1

* Thu Mar 24 2022 umeabot <umeabot> 1.3.204.1-2.mga9
+ Revision: 1825150
- Mageia 9 Mass Rebuild

* Mon Mar 07 2022 akien <akien> 1.3.204.1-1.mga9
+ Revision: 1789525
- Vulkan SDK 1.3.204.1
- Add update instructions for the full Vulkan SDK

* Wed Dec 30 2020 luigiwalser <luigiwalser> 1.2.162.0-1.mga8
+ Revision: 1666091
- 1.2.162.0

* Mon Oct 12 2020 akien <akien> 1.2.154.0-1.mga8
+ Revision: 1633744
- SDK 1.2.154.0

* Mon Feb 17 2020 akien <akien> 1.2.131.1-2.mga8
+ Revision: 1536919
- SDK 1.2.131.1

* Sun Feb 16 2020 daviddavid <daviddavid> 1.1.121.0-2.mga8
+ Revision: 1534145
- use new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Wed Sep 25 2019 akien <akien> 1.1.121.0-1.mga8
+ Revision: 1445837
- SDK 1.1.121.0

* Thu Apr 18 2019 akien <akien> 1.1.106.0-1.mga7
+ Revision: 1393153
- SDK 1.1.106.0

* Tue Mar 26 2019 akien <akien> 1.1.101.0-1.mga7
+ Revision: 1380448
- SDK 1.1.101.0

* Mon Dec 10 2018 akien <akien> 1.1.92.0-1.mga7
+ Revision: 1339896
- Simplify and adapt to Mageia
- import vulkan-headers from Fedora Rawhide


* Mon Dec 03 2018 Dave Airlie <airlied@redhat.com> - 1.1.92.0-1
- Update to 1.1.92.0

* Sat Oct 20 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.1.85.0-1
- Update to 1.1.85.0

* Tue Aug 07 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.1.82.0-1
- Update to 1.1.82.0

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.77.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Jun 22 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.1.77.0-1
- Initial package
